@@ -2,11 +2,11 @@ import logging
 from flask import Blueprint
 from flask.globals import _app_ctx_stack, _request_ctx_stack
 from werkzeug.urls import url_parse
-from forms import GeneralModelConverter
+from .forms import GeneralModelConverter
 from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget
 from .models.filters import Filters, FilterRelationOneToManyEqual
 from .actions import ActionItem
-from urltools import *
+from .urltools import *
 
 log = logging.getLogger(__name__)
 
@@ -740,17 +740,6 @@ class BaseCRUDView(BaseModelView):
             field.data = rel_obj
 
 
-    def debug(self):
-
-        print self.__class__.__name__, "SHOW FS", self.show_fieldsets
-        print self.__class__.__name__, "SHOW COL", self.show_columns
-        print self.__class__.__name__, "ADD FS", self.add_fieldsets
-        print self.__class__.__name__, "ADD COL", self.add_columns
-        print self.__class__.__name__, "EDIT FS", self.edit_fieldsets
-        print self.__class__.__name__, "EDIT COL", self.edit_columns
-        print self.__class__.__name__, "LIST COL", self.list_columns
-
-
     def pre_update(self, item):
         """
             Override this, will be called before update
